<?php 
$OC_Version = array(23,0,8,1);
$OC_VersionString = '23.0.8';
$OC_Edition = '';
$OC_Channel = 'stable';
$OC_VersionCanBeUpgradedFrom = array (
  'nextcloud' => 
  array (
    '22.2' => true,
    '23.0' => true,
  ),
  'owncloud' => 
  array (
    '10.5' => true,
  ),
);
$OC_Build = '2022-08-11T07:55:26+00:00 f6f27bd7f0172817eb2bf6f218a6a5d6131f8e3d';
$vendor = 'nextcloud';
